Auth

Enum Auth 

#[non_exhaustive]
pub enum Auth { Bearer(SecretString), Basic { username: String, password: SecretString, }, ApiKey { name: String, value: SecretString, }, None, }
Authentication method for HTTP requests.

Secret-bearing variants redact their values in Debug output while preserving the plaintext for request header application.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Bearer(SecretString)

Bearer token authentication: Authorization: Bearer <token>



Basic

HTTP Basic authentication: Authorization: Basic <base64(username:password)>

Fields

username: String

Username for basic authentication

password: SecretString

Password for basic authentication



ApiKey

API key authentication: custom header with key value

Fields

name: String

Header name for the API key

value: SecretString

API key value



None

No authentication.

Implementations

Source

impl Auth

pub fn bearer(token: impl Into<String>) -> Self

Creates a Bearer token auth from plaintext.

pub fn bearer_secret(token: SecretString) -> Self

Creates a Bearer token auth from a redacting secret.

pub fn basic(username: impl Into<String>, password: impl Into<String>) -> Self

Creates a Basic auth from a plaintext password.

pub fn basic_secret(username: impl Into<String>, password: SecretString) -> Self

Creates a Basic auth from a redacting password secret.

pub fn api_key(name: impl Into<String>, value: impl Into<String>) -> Self

Creates an API key auth with custom header name and plaintext value.

pub fn api_key_secret(name: impl Into<String>, value: SecretString) -> Self

Creates an API key auth with a custom header name and redacting secret value.

pub fn header(&self) -> AppResult<Option<(String, String)>>

Returns the header name and value for this authentication method.

Errors

Returns an error when the configured API-key header is invalid.